@@ -112,7 +112,8 @@ struct InfoField info_field_printf(const gchar *name, const gchar *format, ...)
 void info_group_strip_extra(struct InfoGroup *group)
 {
     guint fi;
-    char *val, *oldval;
+    const char *val;
+    char *oldval;
     struct InfoField *field;
 
     for (fi = 0; fi < group->fields->len; fi++) {
