@@ -585,6 +585,10 @@ gchar *callback_os(void)
                    info_field_update(_("Load Average"), 10000),
                    info_field_last());
 
+    info_add_group(info, _("Note"),
+                   info_field(_("Logo"),_("belongs to distro and may be reg. trademark")),
+                   info_field_last());
+
     p=info_flatten(info);
     g_free(distro);
     g_free(distro_icon);
@@ -654,11 +658,13 @@ gchar *callback_security(void)
 	    if (g_strstr_len(contents, -1, "Not affected") )
 	        icon = "circle_green_check.svg";
 
-            if (g_str_has_prefix(contents, "Mitigation:") ||
+            if (g_str_has_prefix(contents, "KVM: Mitigation:") ||
+                g_str_has_prefix(contents, "Mitigation:") ||
                 g_str_has_prefix(contents, "mitigation:"))
                 icon = "circle_yellow_exclaim.svg";
 
-            if (g_strstr_len(contents, -1, "Vulnerable") ||
+            if (g_str_has_prefix(contents, "Unknown:") ||
+                g_strstr_len(contents, -1, "Vulnerable") ||
                 g_strstr_len(contents, -1, "vulnerable"))
                 icon = "circle_red_x.svg";
 
