@@ -34,28 +34,30 @@ typedef struct {
 } AptFlavor;
 
 static const AptFlavor apt_flavors[] = {
-    { "Puppy Linux",    "puppy",           "/etc/DISTRO_SPECS",            "/etc/DISTRO_SPECS",          "DISTRO_VERSION="      },
-    { "Winux",          "winux",           "/usr/bin/winux-driver-manager","/etc/os-release",            "PRETTY_NAME=\"Winux " },
-    { "Vendefoul Wolf", "Vendefoul",       "/opt/vendefoulwolf.png",       "/etc/os-release",            "VERSION_ID="          },
-    { "Parrot Security","parrot",          "parrot-updater",               "/etc/os-release",            "VERSION_ID="          },
-    { "Bodhi Linux",    "bodhi",           "bodhi-appcenter",              "/etc/bodhi/info",            "RELEASE="             },
-    { "MX Linux",       "mxlinux",         "mx-welcome",                   "/etc/mx-version",            "MX-"                  },
-    { "Raspbian",       "raspbian",        "raspbian-archive-keyring",     "/etc/os-release",            "VERSION_ID="          },
-    { "Armbian",        "armbian",         "armbian-config",               "/etc/armbian-image-release", "VERSION="             },
-    { "Raspberry Pi",   "raspberry-pi",    "rpi-update",                   "/etc/os-release",            "VERSION_ID="          },
-    { "RevyOS",         "revyos",          "revyos-keyring",               "/etc/revyos-release",        "BUILD_ID="            },
-    { "PureOS",         "pureos",          "pureos-settings",              "/etc/os-release",            "VERSION_ID="          },
-    { "Xubuntu",        "xubuntu",         "xubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
-    { "Kubuntu",        "kubuntu",         "kubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
-    { "Lubuntu",        "lubuntu",         "lubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
-    { "Edubuntu",       "edubuntu",        "edubuntu-desktop",             "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu Server",  "ubuntu",          "ubuntu-server",                "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu MATE",    "ubuntu-mate",     "ubuntu-mate-desktop",          "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu Budgie",  "ubuntu-budgie",   "ubuntu-budgie-desktop",        "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu Kylin",   "ubuntu-kylin",    "ubuntukylin-desktop",          "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu Studio",  "ubuntu-studio",   "ubuntustudio-desktop",         "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu Desktop", "ubuntu",          "ubuntu-desktop",               "/etc/os-release",            "VERSION_ID="          },
-    { "Ubuntu GNOME",   "ubuntu-gnome",    "ubuntu-gnome-desktop",         "/etc/os-release",            "VERSION_ID="          },//dead
+    { "PCLinuxOS Debian", "pclinuxos",       "/etc/pclinuxos_version",       "/etc/os-release",            "VERSION_ID="          },
+    { "PCLinuxOS",        "pclinuxos",       "/etc/pclinuxos_version",       "/etc/os-release",            "VERSION_ID="          },
+    { "Puppy Linux",      "puppy",           "/etc/DISTRO_SPECS",            "/etc/DISTRO_SPECS",          "DISTRO_VERSION="      },
+    { "Winux",            "winux",           "/usr/bin/winux-driver-manager","/etc/os-release",            "PRETTY_NAME=\"Winux " },
+    { "Vendefoul Wolf",   "Vendefoul",       "/opt/vendefoulwolf.png",       "/etc/os-release",            "VERSION_ID="          },
+    { "Parrot Security",  "parrot",          "parrot-updater",               "/etc/os-release",            "VERSION_ID="          },
+    { "Bodhi Linux",      "bodhi",           "bodhi-appcenter",              "/etc/bodhi/info",            "RELEASE="             },
+    { "MX Linux",         "mxlinux",         "mx-welcome",                   "/etc/mx-version",            "MX-"                  },
+    { "Raspbian",         "raspbian",        "raspbian-archive-keyring",     "/etc/os-release",            "VERSION_ID="          },
+    { "Armbian",          "armbian",         "armbian-config",               "/etc/armbian-image-release", "VERSION="             },
+    { "Raspberry Pi",     "raspberry-pi",    "rpi-update",                   "/etc/os-release",            "VERSION_ID="          },
+    { "RevyOS",           "revyos",          "revyos-keyring",               "/etc/revyos-release",        "BUILD_ID="            },
+    { "PureOS",           "pureos",          "pureos-settings",              "/etc/os-release",            "VERSION_ID="          },
+    { "Xubuntu",          "xubuntu",         "xubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
+    { "Kubuntu",          "kubuntu",         "kubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
+    { "Lubuntu",          "lubuntu",         "lubuntu-desktop",              "/etc/os-release",            "VERSION_ID="          },
+    { "Edubuntu",         "edubuntu",        "edubuntu-desktop",             "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu Server",    "ubuntu",          "ubuntu-server",                "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu MATE",      "ubuntu-mate",     "ubuntu-mate-desktop",          "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu Budgie",    "ubuntu-budgie",   "ubuntu-budgie-desktop",        "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu Kylin",     "ubuntu-kylin",    "ubuntukylin-desktop",          "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu Studio",    "ubuntu-studio",   "ubuntustudio-desktop",         "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu Desktop",   "ubuntu",          "ubuntu-desktop",               "/etc/os-release",            "VERSION_ID="          },
+    { "Ubuntu GNOME",     "ubuntu-gnome",    "ubuntu-gnome-desktop",         "/etc/os-release",            "VERSION_ID="          },//dead
     { NULL }
 };
 void apt_flavors_scan(gchar **pretty_name, gchar **codename, gchar **id, gchar **orig_id, gchar **orig_name) {
@@ -476,7 +478,7 @@ static Distro parse_os_release(void)
     gchar *id = NULL;
     gchar *version = NULL;
     gchar *codename = NULL;
-    gchar **split, *contents, **line;
+    gchar **split, *contents, *content2, **line;
     gchar *orig_id=NULL, *orig_name=NULL;
 
     //some overrides the /etc/os-release, so we use usr/lib first and fixes distro via Apt, OLD DISTRO fallback to /etc/os.
@@ -484,6 +486,12 @@ static Distro parse_os_release(void)
         if (!g_file_get_contents("/etc/os-release", &contents, NULL, NULL))
             return (Distro) {};
 
+    //force /etc/os-release for some distros
+    if (!g_file_get_contents("/etc/os-release", &content2, NULL, NULL)) return (Distro) {};
+    if(strstr(content2,"CachyOS")) {
+        g_free(contents);
+	contents=content2;
+    } else g_free(content2);
 
     split = g_strsplit(contents, "\n", 0);
     g_free(contents);
