@@ -597,10 +597,13 @@ gchar *processor_name(GSList *processors) {
         char *search_str;
         char *vendor;
         char *soc;
-    } dt_compat_searches[] = {
+    } dt_compat_searches[] = { 
+        { "allwinner,sun8i-h3", "Allwinner", "H3" },
+        { "allwinner,sun50i-h616", "Allwinner", "H616" },//Orange PI Zero3
         { "amlogic,a311d", "Amlogic", "A311D (Vim3)" }, // VIM3
         { "amlogic,s905w", "Amlogic", "S905W" },
         { "amlogic,s912", "Amlogic", "S912" },
+        { "amlogic,sc2", "Amlogic", "S905X4 (SC2)" },//Meson SC2
         { "apple,t8132", "Apple", "T8132 (M4)" },
         { "apple,t8122", "Apple", "T8122 (M3)" },
         { "apple,t8112", "Apple", "T8112 (M2)" },
@@ -623,11 +626,12 @@ gchar *processor_name(GSList *processors) {
         { "brcm,bcm2837", "Broadcom", "BCM2837 (RPi3)" }, // RPi 3
         { "brcm,bcm2836", "Broadcom", "BCM2836 (RPi2)" }, // RPi 2
         { "brcm,bcm2835", "Broadcom", "BCM2835 (RPi1)" }, // RPi 1
-        { "friendlyelec,nanopi-k1-plus", "Allwinner", "SUN50I-H5 (K1+)" }, // K1+
+        { "friendlyelec,nanopi-k1-plus", "Allwinner", "H5 (K1+)" }, // K1+
         { "hardkernel,odroid-c2", "Amlogic", "S905 (C2)" }, // C2
         { "hardkernel,odroid-n2", "Amlogic", "S922x (N2)" }, // N2
         { "mediatek,mt8173", "MediaTek", "MT8173" },
         { "mediatek,mt8183", "MediaTek", "MT8183" },
+        { "mediatek,mt8167", "MediaTek", "MT8167" },
         { "mediatek,mt6895", "MediaTek", "MT6895" },
         { "mediatek,mt6799", "MediaTek", "MT6799 (Helio X30)" },
         { "mediatek,mt6799", "MediaTek", "MT6799 (Helio X30)" },
@@ -648,10 +652,12 @@ gchar *processor_name(GSList *processors) {
         { "mediatek,mt6732", "MediaTek", "MT6732" },
         { "nvidia,tegra", "nVidia", "Tegra-family" },
         { "qcom,pineapple", "Qualcomm", "Pineapple (SD8g3)"},
+        { "qcom,sm8150", "Qualcomm", "SM8150"},
         { "qcom,sm8550", "Qualcomm", "SM8550 (SD8g2)"},
         { "qcom,msm8939", "Qualcomm", "Snapdragon 615"},
         { "qcom,msm", "Qualcomm", "Snapdragon-family"},
         { "qcom,x1e80100", "Qualcomm", "Snapdragon X Elite"},
+        { "qcom,x1p42100", "Qualcomm", "Snapdragon X Plus"},
         { "rockchip,rk3288", "Rockchip", "RK3288" }, // Asus Tinkerboard
         { "rockchip,rk3328", "Rockchip", "RK3328" }, // Firefly Renegade
         { "rockchip,rk3399", "Rockchip", "RK3399" }, // Firefly Renegade Elite
