@@ -63,11 +63,15 @@ gchar *nvme_pci_sections(pcid *p) {
     if (p->pcie_width_curr) {
         pcie_str = g_strdup_printf("[%s]\n"
                      /* Addy */    "%s=PCI/%s\n"
+                     /* Width (cur) */  "%s=x%u\n"
                      /* Width (max) */  "%s=x%u\n"
+                     /* Speed (cur) */  "%s=%0.1f %s\n"
                      /* Speed (max) */  "%s=%0.1f %s\n",
                     _("PCI Express"),
                     _("Location"), p->slot_str,
+                    _("Link Width"), p->pcie_width_curr,
                     _("Maximum Link Width"), p->pcie_width_max,
+		    _("Link Speed"), p->pcie_speed_curr, _("GT/s"),
                     _("Maximum Link Speed"), p->pcie_speed_max, _("GT/s") );
     } else
         pcie_str = strdup("");
@@ -355,9 +359,10 @@ gboolean __scan_udisks2_devices(void) {
                                         disk->smart_temperature);
 
             if (disk->smart_attributes != NULL) {
-                moreinfo = h_strdup_cprintf(_("[S.M.A.R.T. Attributes]\n"
-                                            "Attribute=<tt>Value      / Normalized / Worst / Threshold</tt>\n"),
-                                            moreinfo);
+	        if(ext->nvme_controller)
+                    moreinfo = h_strdup_cprintf(_("[S.M.A.R.T. Attributes]\nAttribute=<tt>Value</tt>\n"), moreinfo);
+		else
+                    moreinfo = h_strdup_cprintf(_("[S.M.A.R.T. Attributes]\nAttribute=<tt>Value      / Normalized / Worst / Threshold</tt>\n"), moreinfo);
 
                 attrib = disk->smart_attributes;
 
@@ -372,7 +377,13 @@ gboolean __scan_udisks2_devices(void) {
                             tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " ms", tmp, attrib->interpreted);
                             break;
                         case UDSK_INTPVAL_HOURS:
-                            tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " h", tmp, attrib->interpreted);
+			    if(attrib->interpreted<24){
+			        tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " h", tmp, attrib->interpreted);
+			    } else if (attrib->interpreted<24*365){
+			        tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " days", tmp, attrib->interpreted/24);
+			    } else {
+			      tmp = h_strdup_cprintf("%0.1f years", tmp, (double)attrib->interpreted/24/365);
+			    }
                             break;
                         case UDSK_INTPVAL_CELSIUS:
                             tmp = h_strdup_cprintf("%" G_GINT64_FORMAT "°C", tmp, attrib->interpreted);
@@ -382,6 +393,12 @@ gboolean __scan_udisks2_devices(void) {
                                                             "%" G_GINT64_FORMAT " sectors", attrib->interpreted),
                                                    tmp, attrib->interpreted);
                             break;
+                        case UDSK_INTPVAL_TB:
+                            tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " TB", tmp, attrib->interpreted);
+			    break;
+                        case UDSK_INTPVAL_PROCENT:
+                            tmp = h_strdup_cprintf("%" G_GINT64_FORMAT " %%", tmp, attrib->interpreted);
+                            break;
                         case UDSK_INTPVAL_DIMENSIONLESS:
                         default:
                             tmp = h_strdup_cprintf("%" G_GINT64_FORMAT, tmp, attrib->interpreted);
@@ -392,21 +409,22 @@ gboolean __scan_udisks2_devices(void) {
                     j = g_utf8_strlen(tmp, -1);
                     if (j < 13) tmp = h_strdup_cprintf("%*c", tmp, 13 - j, ' ');
 
-                    if (attrib->value != -1)
-                        tmp = h_strdup_cprintf("%-13d", tmp, attrib->value);
-                    else
-                        tmp = h_strdup_cprintf("%-13s", tmp, "???");
+		    if(!ext->nvme_controller){
+		        if (attrib->value != -1)
+                            tmp = h_strdup_cprintf("%-13d", tmp, attrib->value);
+			else
+                            tmp = h_strdup_cprintf("%-13s", tmp, "???");
 
-                    if (attrib->worst != -1)
-                        tmp = h_strdup_cprintf("%-8d", tmp, attrib->worst);
-                    else
-                        tmp = h_strdup_cprintf("%-8s", tmp, "???");
-
-                    if (attrib->threshold != -1)
-                        tmp = h_strdup_cprintf("%d", tmp, attrib->threshold);
-                    else
-                        tmp = h_strdup_cprintf("???", tmp);
+                        if (attrib->worst != -1)
+                            tmp = h_strdup_cprintf("%-8d", tmp, attrib->worst);
+                        else
+                            tmp = h_strdup_cprintf("%-8s", tmp, "???");
 
+                        if (attrib->threshold != -1)
+                            tmp = h_strdup_cprintf("%d", tmp, attrib->threshold);
+                        else
+                            tmp = h_strdup_cprintf("???", tmp);
+		    }
 
                     alabel = attrib->identifier;
                     for (i = 0; smart_attrib_info[i].identifier != NULL; i++) {
@@ -416,9 +434,11 @@ gboolean __scan_udisks2_devices(void) {
                         }
                     }
 
-                    moreinfo = h_strdup_cprintf(_("(%d) %s=<tt>%s</tt>\n"),
-                                            moreinfo,
-                                            attrib->id, alabel, tmp);
+		    if(ext->nvme_controller)
+		        moreinfo = h_strdup_cprintf(_("%s=<tt>%s</tt>\n"), moreinfo, alabel, tmp);
+		    else
+		        moreinfo = h_strdup_cprintf(_("(%d) %s=<tt>%s</tt>\n"), moreinfo, attrib->id, alabel, tmp);
+
                     g_free(tmp);
                     attrib = attrib->next;
                 }
