@@ -148,11 +148,10 @@ void cb_theme6()
 
 void cb_disable_theme()
 {
-    Shell *shell = shell_get_main_shell();
-    // *shelltree=shell->tree;
-    char theme_st[400];
     GKeyFile *key_file = g_key_file_new();
 #if GTK_CHECK_VERSION(3, 0, 0)
+    Shell *shell = shell_get_main_shell();
+    char theme_st[400];
     GtkCssProvider *provider;
     provider = gtk_css_provider_new();
     GtkCssProvider *provider2;
@@ -406,7 +405,6 @@ void cb_about()
 	"Translated by:",
 	"Alexander Münch",
 	"micrococo",
-	"yolanteng0",
 	"Yunji Lee",
 	"Hugo Carvalho",
 	"Paulo Giovanni Pereira",
@@ -419,6 +417,9 @@ void cb_about()
 	"thiagodalsoto (Brazilian)",
 	"serkan-maker (Turkish)",
 	"ReVe1uv (Chinese)",
+	"yolateng0 (France)",
+	"EkaterinePapava (Georgian)",
+	"yeager (Swedish)",
         "",
 	"Artwork by:",
         "Jakub Szypulka",
