@@ -66,7 +66,9 @@ static void info_selected_show_extra(const gchar *tag);
 static gboolean reload_section(gpointer data);
 static gboolean rescan_section(gpointer data);
 static gboolean update_field(gpointer data);
+#if GTK_CHECK_VERSION(3,0,0)
 static GSettings *settings=NULL;
+#endif
 /*
  * Globals ********************************************************************
  */
@@ -352,35 +354,30 @@ static void destroy_me(void){
 #if GTK_CHECK_VERSION(3, 0, 0)
 int update=0;
 int schemeDark=0;
-int changed2dark=0;
 int newgnome=0;
 static void stylechange2_me(void)
 {
   if(update==1){
     GtkStyleContext *sctx=gtk_widget_get_style_context(GTK_WIDGET(shell->window));
     GdkRGBA color;
-    gtk_style_context_lookup_color(sctx, "theme_bg_color", &color);
+    gtk_style_context_lookup_color(sctx, "theme_text_color", &color);
     gint darkmode=0;
-    if((color.red+color.green+color.blue)<=1.5) darkmode=1;
+    if((color.red+color.green+color.blue)>=1.5) darkmode=1;
     //
     if(schemeDark && (!darkmode) ) {
         if(newgnome){
-            darkmode=1;
             //g_print("We need to change GTK_THEME to dark\n");
             GtkSettings *set;
 	    set=gtk_settings_get_default();
 	    g_object_set(set,"gtk-theme-name","HighContrastInverse", NULL);
-	    changed2dark=1;
 	}
     }
-    if( (!schemeDark) && darkmode && changed2dark ) {
+    if( (!schemeDark) && darkmode){
         if(newgnome){
-	    darkmode=0;
             //g_print("We need to change GTK_THEME to light\n");
             GtkSettings *set;
 	    set=gtk_settings_get_default();
 	    g_object_set(set,"gtk-theme-name","Adwaita", NULL);
-	    changed2dark=0;
 	}
     }
     //
@@ -398,7 +395,7 @@ static void stylechange2_me(void)
 //gsettings
 static void stylechange3_me(void)
 {
-    gchar *theme=NULL,*scale=NULL;
+  gchar *theme=NULL;//,*scale=NULL;
     int newDark=0,i=0;
     gchar **keys=NULL;
     if(settings && !newgnome) keys=g_settings_list_keys(settings);
@@ -571,7 +568,8 @@ static void create_window(void)
 #if GTK_CHECK_VERSION(3, 0, 0)
     gtk_widget_set_valign(GTK_WIDGET(shell->progress), GTK_ALIGN_CENTER);
 #else
-    gtk_misc_set_alignment(GTK_MISC(shell->progress), 0.0, 0.5);
+    //Results in conversion error - just disable for GTK2
+    //gtk_misc_set_alignment(GTK_MISC(shell->progress), 0.0, 0.5);
 #endif
     gtk_progress_bar_set_pulse_step(GTK_PROGRESS_BAR(shell->progress),0.10);
     gtk_widget_hide(shell->progress);
@@ -650,10 +648,7 @@ static void create_window(void)
     if(!check_program("glxinfo"))                                 {p=pkgok;pkgok=g_strconcat("glxinfo / mesa-utils\n", pkgok, NULL);g_free(p);}
     if(strstr(PACK_REQ,"iperf") && !check_program("iperf3"))      {p=pkgok;pkgok=g_strconcat("iperf3\n", pkgok, NULL);g_free(p);}
     if(strstr(PACK_REQ,"sysbench") && !check_program("sysbench")) {p=pkgok;pkgok=g_strconcat("sysbench\n", pkgok, NULL);g_free(p);}
-#if(HARDINFO2_QT5)
-    //no binary in qt5-base package
-    //if(!check_program("qmake-qt5")) {p=pkgok;pkgok=g_strconcat("qt5-base\n", pkgok, NULL);g_free(p);}
-#endif
+    //no binary in qt5/6-base package
     //randr optional
     //if(strstr(PACK_REQ,"randr") && !check_program("xrandr"))      {p=pkgok;pkgok=g_strconcat("xrandr\n", pkgok, NULL);g_free(p);}
     //fwupd optional
@@ -673,7 +668,7 @@ static void create_window(void)
     }
 }
 
-static void view_menu_select_entry(gpointer data, gpointer data2)
+/*static void view_menu_select_entry(gpointer data, gpointer data2)
 {
     GtkTreePath *path;
     GtkTreeIter *iter = (GtkTreeIter *) data2;
@@ -684,7 +679,7 @@ static void view_menu_select_entry(gpointer data, gpointer data2)
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(shell->tree->view), path, NULL,
 			     FALSE);
     gtk_tree_path_free(path);
-}
+}*/
 
 
 void shell_add_modules_to_gui(gpointer _shell_module, gpointer _shell_tree)
@@ -890,6 +885,7 @@ void shell_init(GSList * modules)
     shell_action_set_property("SyncManagerAction", "is-important", TRUE);
     shell_action_set_property("UpdateAction", "is-important", TRUE);
 
+
     path = g_build_filename(g_get_user_config_dir(), "hardinfo2","blobs-update-version.json", NULL);
     fd = open(path,O_RDONLY);
     if(fd>=0){
@@ -964,6 +960,12 @@ void shell_init(GSList * modules)
     gtk_widget_hide(shell->notebook);
     gtk_widget_hide(shell->note->event_box);
 
+    //Set SidePane+Toolbar active on start
+    shell_action_set_property("SidePaneAction", "active", TRUE);
+    shell_set_side_pane_visible(TRUE);
+    shell_action_set_property("ToolbarAction", "active", TRUE);
+    shell_ui_manager_set_visible("/MainMenuBarAction", TRUE);
+
     /* Should select Computer Summary (note: not Computer/Summary) */
     g_idle_add(select_first_tree_item, NULL);
 }
@@ -2433,7 +2435,8 @@ gboolean key_label_is_escaped(const gchar *key) {
 
 gchar *key_mi_tag(const gchar *key) {
     static char flag_list[] = "*!^@";
-    gchar *p = (gchar*)key, *l, *t;
+    gchar *p = (gchar*)key, *t;
+    const gchar *l;
 
     if (key_is_flagged(key)) {
         l = strchr(key+1, '$');
